@@ -1,6 +1,7 @@
 mod calls;
 mod callsigns;
 mod connection;
+mod news;
 mod nodes;
 mod rubrics;
 mod statistics;
@@ -10,6 +11,7 @@ mod transmitters;
 pub use calls::Call;
 pub use callsigns::Callsign;
 pub use connection::Connection;
+pub use news::News;
 pub use nodes::Node;
 pub use rubrics::Rubric;
 pub use statistics::Statistics;
